@@ -1057,7 +1057,7 @@ _gth_media_viewer_page_set_uri (GthMediaViewerPage *self,
 
 	g_object_set (G_OBJECT (self->priv->playbin), "uri", uri, NULL);
 	gst_element_set_state (self->priv->playbin, state);
-	gst_element_get_state (self->priv->playbin, NULL, NULL, GST_CLOCK_TIME_NONE);
+	/*gst_element_get_state (self->priv->playbin, NULL, NULL, GST_CLOCK_TIME_NONE);*/
 }
 
 
